package de.fraunhofer.iem.dataprovider

import de.fraunhofer.iem.dataprovider.configuration.InitialProjects
import de.fraunhofer.iem.dataprovider.logger.getLogger
import de.fraunhofer.iem.dataprovider.toolRun.service.ToolRunService
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import org.springframework.boot.context.event.ApplicationReadyEvent
import org.springframework.context.event.EventListener
import org.springframework.stereotype.Component

@Component
class StartUpHandler(val toolRunService: ToolRunService, val initialProjects: InitialProjects) {
    private val logger = getLogger(javaClass)
    val coroutineScope = CoroutineScope(Dispatchers.Default)

    @EventListener(ApplicationReadyEvent::class)
    fun queryProjects() {
        logger.info("Loading initial projects $initialProjects")

        initialProjects.projectIds.forEach { projectId ->
            if (projectId >= 0) {
                coroutineScope.launch {
                    toolRunService.createToolRunForRepository(projectId)
                }
            }
        }
    }
}
